==> owntone-28.5.tar.xz: owntone-28.5/src/parsers/daap_parser.h <==
/* A Bison parser, made by GNU Bison 3.5.1.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Undocumented macros, especially those whose name start with YY_,
   are private implementation details.  Do not rely on them.  */

#ifndef YY_DAAP_PARSERS_DAAP_PARSER_H_INCLUDED
# define YY_DAAP_PARSERS_DAAP_PARSER_H_INCLUDED
/* Debug traces.  */
#ifndef DAAP_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define DAAP_DEBUG 1
#  else
#   define DAAP_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define DAAP_DEBUG 1
# endif /* ! defined YYDEBUG */
#endif  /* ! defined DAAP_DEBUG */
#if DAAP_DEBUG
extern int daap_debug;
#endif
/* "%code requires" blocks.  */
#line 192 "parsers/daap_parser.y"

struct daap_result {
  char str[1024];
  int offset;
  int err;
  char errmsg[128];
};

#line 65 "parsers/daap_parser.h"

/* Token type.  */
#ifndef DAAP_TOKENTYPE
# define DAAP_TOKENTYPE
  enum daap_tokentype
  {
    DAAP_T_KEY = 258,
    DAAP_T_VALUE = 259,
    DAAP_T_WILDCARD = 260,
    DAAP_T_EQUAL = 261,
    DAAP_T_NOT = 262,
    DAAP_T_QUOTE = 263,
    DAAP_T_PARENS = 264,
    DAAP_T_NEWLINE = 265,
    DAAP_T_AND = 266,
    DAAP_T_OR = 267
  };
#endif

/* Value type.  */
#if ! defined DAAP_STYPE && ! defined DAAP_STYPE_IS_DECLARED
union DAAP_STYPE
{
#line 404 "parsers/daap_parser.y"

  char *str;
  int ival;
  struct ast *ast;

#line 95 "parsers/daap_parser.h"

};
typedef union DAAP_STYPE DAAP_STYPE;
# define DAAP_STYPE_IS_TRIVIAL 1
# define DAAP_STYPE_IS_DECLARED 1
#endif



int daap_parse (struct daap_result *result, void *scanner);
/* "%code provides" blocks.  */
#line 42 "parsers/daap_parser.y"

/* Convenience functions for caller to use instead of interfacing with lexer and
   parser directly */
int daap_lex_cb(char *input, void (*cb)(int, const char *));
int daap_lex_parse(struct daap_result *result, const char *input);

#line 114 "parsers/daap_parser.h"

#endif /* !YY_DAAP_PARSERS_DAAP_PARSER_H_INCLUDED  */

==> owntone-29.0.tar.xz: owntone-29.0/src/parsers/daap_parser.h <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_DAAP_PARSERS_DAAP_PARSER_H_INCLUDED
# define YY_DAAP_PARSERS_DAAP_PARSER_H_INCLUDED
/* Debug traces.  */
#ifndef DAAP_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define DAAP_DEBUG 1
#  else
#   define DAAP_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define DAAP_DEBUG 1
# endif /* ! defined YYDEBUG */
#endif  /* ! defined DAAP_DEBUG */
#if DAAP_DEBUG
extern int daap_debug;
#endif
/* "%code requires" blocks.  */
#line 192 "parsers/daap_parser.y"

struct daap_result {
  char str[1024];
  int offset;
  int err;
  char errmsg[128];
};

#line 66 "parsers/daap_parser.h"

/* Token kinds.  */
#ifndef DAAP_TOKENTYPE
# define DAAP_TOKENTYPE
  enum daap_tokentype
  {
    DAAP_EMPTY = -2,
    DAAP_EOF = 0,                  /* "end of file"  */
    DAAP_error = 256,              /* error  */
    DAAP_UNDEF = 257,              /* "invalid token"  */
    DAAP_T_KEY = 258,              /* DAAP_T_KEY  */
    DAAP_T_VALUE = 259,            /* DAAP_T_VALUE  */
    DAAP_T_WILDCARD = 260,         /* DAAP_T_WILDCARD  */
    DAAP_T_EQUAL = 261,            /* DAAP_T_EQUAL  */
    DAAP_T_NOT = 262,              /* DAAP_T_NOT  */
    DAAP_T_QUOTE = 263,            /* DAAP_T_QUOTE  */
    DAAP_T_PARENS = 264,           /* DAAP_T_PARENS  */
    DAAP_T_NEWLINE = 265,          /* DAAP_T_NEWLINE  */
    DAAP_T_AND = 266,              /* DAAP_T_AND  */
    DAAP_T_OR = 267                /* DAAP_T_OR  */
  };
  typedef enum daap_tokentype daap_token_kind_t;
#endif

/* Value type.  */
#if ! defined DAAP_STYPE && ! defined DAAP_STYPE_IS_DECLARED
union DAAP_STYPE
{
#line 404 "parsers/daap_parser.y"

  char *str;
  int ival;
  struct ast *ast;

#line 101 "parsers/daap_parser.h"

};
typedef union DAAP_STYPE DAAP_STYPE;
# define DAAP_STYPE_IS_TRIVIAL 1
# define DAAP_STYPE_IS_DECLARED 1
#endif




int daap_parse (struct daap_result *result, void *scanner);

/* "%code provides" blocks.  */
#line 42 "parsers/daap_parser.y"

/* Convenience functions for caller to use instead of interfacing with lexer and
   parser directly */
int daap_lex_cb(char *input, void (*cb)(int, const char *));
int daap_lex_parse(struct daap_result *result, const char *input);

#line 122 "parsers/daap_parser.h"

#endif /* !YY_DAAP_PARSERS_DAAP_PARSER_H_INCLUDED  */
